import useIsUnmounted from './use-is-unmounted.js';
import { loader } from '@monaco-editor/react';
import { registerDolphinDBLanguage } from '../index.js';
let monacoInitialized = false;
let initMonacoPromise = null;
export function useInitDolphinDBbMonaco(options) {
    const { beforeMonacoInit, onMonacoInit, onMonacoInitFailed, dolphinDBLanguageOptions } = options;
    const isUnmountedRef = useIsUnmounted();
    function setInitMonacoPromiseThenAndCatch(p) {
        p.then((monaco) => {
            if (!isUnmountedRef.current) {
                onMonacoInit?.(monaco);
            }
        })
            .catch((err) => {
            onMonacoInitFailed?.(err);
        })
            .finally(() => {
            initMonacoPromise = null;
        });
    }
    // 已完成初始化
    if (monacoInitialized) {
        return;
    }
    // 正在初始化
    if (initMonacoPromise) {
        setInitMonacoPromiseThenAndCatch(initMonacoPromise);
        return;
    }
    // 未初始化
    initMonacoPromise = (async () => {
        await beforeMonacoInit?.();
        const monaco = await loader.init();
        await registerDolphinDBLanguage(monaco, dolphinDBLanguageOptions);
        await document.fonts.ready;
        monacoInitialized = true;
        return monaco;
    })();
    setInitMonacoPromiseThenAndCatch(initMonacoPromise);
}
//# sourceMappingURL=shared.js.map